# FastApi et distribution de fichier

![tag](python)
![tag](fastapi)

IL est possible avec le module **fastapi** de distribuer des fichiers html simple (et pas forcement que de l'api)

On peut le faire de 3 façons différentes

- via un template jinja
- via un dossier source
- spécifiquement via un fichier

installation des librairies

> pip install fastapi nicegui uvicorn

```python
import os
from fastapi import FastAPI, Request
from fastapi.templating import Jinja2Templates
from fastapi.staticfiles import StaticFiles
from fastapi.responses import FileResponse

app = FastAPI()

# Définition du dossier contenant les templates HTML
templates = Jinja2Templates(directory="templates")

# Route pour servir une page HTML
@app.get("/")
async def home(request: Request):
return templates.TemplateResponse("index.html", {"request": request})

@app.get("/basic")
async def home():
return FileResponse(os.path.abspath(os.path.join("static", "basic.html")))


# Servir des fichiers statiques (CSS, JS, images...)
app.mount("/static", StaticFiles(directory="static"), name="static")
```

on peut lancer ce fichier main.py via la commande

> uvicorn main:app --reload

votre dossier contient

- un fichier main.py
- un fichier templates\index.html
- un fichier static\style.css
- un fichier static\basic.html

index.html

```html
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Page Web avec FastAPI</title>
    <link rel="stylesheet" href="/static/style.css">
</head>
<body>
    <h1>Bienvenue sur ma page FastAPI !</h1>
</body>
</html>
```


basic.html

```html
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Page Web avec FastAPI Basic</title>
    <link rel="stylesheet" href="/static/style.css">
</head>
<body>
    <h1>Bienvenue sur ma page FastAPI Basic !</h1>
</body>
</html>
```


on peut tester les url

- http://127.0.0.1:8000/
- http://127.0.0.1:8000/basic
- http://127.0.0.1:8000/static/basic.html
- http://127.0.0.1:8000/static/style.css